@@ -138,12 +138,19 @@ class Speller:
         return 0
 
     def remove_word(self, word):
-        try: del self.nlp_data[word]                
-        except KeyError: print("Word",word,"not found")
+        try: 
+            del self.nlp_data[word]
+            return True              
+        except KeyError: 
+            return False
     
     def add_word(self, word):
-        try: self.nlp_data[word]+=1
-        except KeyError: self.nlp_data[word]=1
+        try: 
+            self.nlp_data[word]+=1
+            return True
+        except KeyError: 
+            self.nlp_data[word]=1
+            return False
 
     def candidates(self, word, max_suggestions=100, capitalize=False, labels=False):
         """
@@ -187,7 +194,7 @@ class Speller:
         for ngram in sentence.split():
             deny_alpha="[^"+alphabets[self.lang]+"]"
             word=re.sub(f"{deny_alpha}+$","",re.sub(f"^{deny_alpha}+","",ngram.lower()))
-            if not re.match(r'\d+', word):
+            if word and not re.match(r'\d+', word):
                 captal_letter=False
                 if ngram[0].isupper():
                     captal_letter=True
